/*****************************************************************/
/* FILE:        	w1indvars.sas                            */
/* PROJECT: 		Healthy, Wealthy, & Wise (AHEAD Data)    */
/* FACULTY:		Dan McFadden                             */
/* AUTHOR:		Angela Merrill/Tiago Ribeiro             */
/* LAST UPDATE:		Jan 2003                                 */
/* PROGRAM DESC:	Code Wave 1 respondent level vars        */
/* CONTACT:             tribeiro@econ.berkeley.edu               */
/*****************************************************************/
%global thisfile;
%let lastfile=&thisfile;
%let thisfile=w1indvars;
proc printto log="&thisfile..log" print="&thisfile..lst" new; run;
	

%include "~/ribeiro/datagen/header.inc";
options ps=2000 ls=150;

/****************************************************/ 
/******* Macro to read relevant raw data ************/
/****************************************************/ 
%macro h;

x zcat "&rawc1/br21.ssd01.Z"   > "&local/br21.ssd01";

*proc contents data=local.bhh21;
*proc contents data=local.bhp21;
*proc contents data=local.bop21;
*proc contents data=local.br21;


data local.w1ind0;
    set local.br21;

/*
V1285               [RESP]    H7. EXPECT LIVE TO AGE
          H7.  (Using a number from 0 to 100), what do you think are the
               chances that you will live to be at least [BORN 1904-1908:
               100; BORN 1909-1913:  95; BORN 1914-1918:  90; BORN 1919-1923:
               85; BORN 1924 OR AFTER: 80]?
 -----------------------------------------------------------------------------
                  N          Mean       Std Dev       Minimum       Maximum
               6141         43.18         34.85          0.00        100.00
                         ABSOLUTELY NO CHANCE.................000
                         ABSOLUTELY CERTAIN...................100
                815      DK................................... .D
                200      RF................................... .R
               1066      INAP, PROXY, BORN IN 1903 [V114] OR BEFORE
*/
    
    if v1285 = .A then v1285=-900;
    if v1285 = .D then v1285=-800;
    if v1285 = .P then v1285=-700;
    if v1285 = .R then v1285=-600;
    
    array tmp{*} _all_;
    do i=1 to dim(tmp);
        if tmp{i} in(.D,.R,.P,.A) then tmp{i}=.; 
        end;
    run;
    
x /bin/rm "&local/br21.ssd01";
    
%mend;
%h;
/****************************************************/



****************************************************;
* CODE INDIVIDUAL-LEVEL DATASET;
****************************************************;

data w1ind0;
    set local.w1ind0;
    rename proxy=proxy1;
run;
proc contents;

%vtic(w1ind0);

data w1ind0;
    set w1ind0;

    %include 'w1ind/demog1.sas';
    %include 'w1ind/health1.sas';
    %include 'w1ind/cogn1.sas';
    %include 'w1ind/parents1.sas';
    %include 'w1ind/adl_iadl1.sas';
    %include 'w1ind/work1.sas';
    %include 'w1ind/subprob1.sas';
run;

%vtoc(w1ind0,);


****************************************************;
* OUTPUT INDIVIDUAL-LEVEL DATASET;
****************************************************;

proc means nmiss n mean std min max;
    var %include "&thisfile..vars";;
run;

proc means nmiss n mean std min max;
    class proxy1;
    var %include "&thisfile..vars";;
run;

data local8.w1indvar;
set w1ind0;
keep hhidpn;
keep %include "&thisfile..vars";;
run;
proc contents;

   /****************************************************/ 
   /*****************End of File************************/ 
   /****************************************************/ 

   %let thisfile=&lastfile;
   proc printto log="&thisfile..log" print="&thisfile..lst"; run;

   /****************************************************/ 
   /****************************************************/ 
   /****************************************************/ 
