/*****************************************************************/
/* FILE:        	w3assets.sas                             */
/* PROJECT: 		Healthy, Wealthy, & Wise (AHEAD Data)    */
/* FACULTY:		Dan McFadden                             */
/* AUTHOR:		Tiago Ribeiro                            */
/* LAST UPDATE:		Jan 2003                                 */
/* PROGRAM DESC:	Code Wave 3 assets and income            */
/* CONTACT:             tribeiro@econ.berkeley.edu               */
/*****************************************************************/
%global thisfile;
%let lastfile=&thisfile;
%let thisfile=w3assets;
proc printto log="&thisfile..log" print="&thisfile..lst" new; run;

%include "~/ribeiro/datagen/header.inc";
 
options ps=2000 ls=150;

 
%macro h;
x zcat "&rawc3/h98pr_r.ssd01.Z" > /tmp/tribeiro/h98pr_r.ssd01;
x zcat "&rawc3/h98j_h.ssd01.Z"  > /tmp/tribeiro/h98j_h.ssd01;
x zcat "&rawc3/h98f_h.ssd01.Z"  > /tmp/tribeiro/h98f_h.ssd01;
x zcat "&rawc3/h98cs_r.ssd01.Z"  > /tmp/tribeiro/h98cs_r.ssd01;
x zcat "&rawc3/h98a_r.ssd01.Z"  > /tmp/tribeiro/h98a_r.ssd01;

/****************************/
/* Preload Variables        */  
/****************************/

data h98pr_r;
     set local.h98pr_r;
     hhidpn=hhid*1000+pn;
     keep
         F111_1
         F112_1
         F113_1
         F114_1
         F115_1
         F116_1
         F117_1
         F118_1
         F119_1
         F120_1
         F121_1
         F122_1
         F123_1
         F124_1
         F125_1
         F126_1
         F127_1
         F128_1
         F129_1
         F130_1;/* Unfolding bracket randomization */

             keep hhidpn;
     keep f288;
run;


/****************************/
/* Cover Screen Variables   */  
/****************************/

data h98cs_r;
     set local.h98cs_r;
     hhidpn=hhid*1000+pn;
     _DSUBHH=DSUBHH+0;  
     _FSUBHH=FSUBHH+0;  
     _HHID=HHID+0;    
     _PN=PN+0;      
     drop DSUBHH FSUBHH HHID PN;
run;

data h98cs_r;
     set h98cs_r;
     rename
     _DSUBHH=DSUBHH  
     _FSUBHH=FSUBHH  
     _HHID=HHID   
     _PN=PN;   
     run;


data h98cs_r;
set h98cs_r;
    keep hhidpn hhid fsubhh dsubhh pn  ;
    cohort=f461; *ahead is q461=1;
    famr3=f688;
    finr3=f689;
    keep f688 f689;
    keep cohort  famr3 finr3 ffamr ffinr;
    keep F517;    *CS11.R IN NURSING HOME;
    keep F721;    *CS26.NURHM: STILL OWN/RENT HOME;
    keep F744;    *CS36C.R CHANGED MAIN RESIDENCE;
    keep F483;    * Proxy;
    keep f456 f497 f542 f518 ;
    run;

proc freq; 
tables 
cohort*finr3*ffinr cohort*famr3*ffamr  / list missing; 


/****************************/
/* Section A Variables      */  
/****************************/
/*
data h98a_r;
     set local.h98a_r;
     hhidpn=hhid*1000+pn;
     keep hhidpn q1101 q1102;
run;
*/
 /****************************/
 /* Section J Variables      */  
 /****************************/

data h98j_h;
    set local.h98j_h;
    _FSUBHH=FSUBHH+0;  
    _HHID=HHID+0;    
    _FPN_FAM=FPN_FAM+0;
    _FPN_FIN=FPN_FIN+0;
    drop FSUBHH HHID;
run;

data h98j_h;
    set h98j_h;
    rename
        _FSUBHH=FSUBHH  
        _HHID=HHID
        _FPN_FAM=FPN_FAM
        _FPN_FIN=FPN_FIN;
drop esubhh dsubhh;
    run;
    


/****************************/
/* Section F Variables      */  
/****************************/

data h98f_h;
    set local.h98f_h;
    _FSUBHH=FSUBHH+0;  
    _HHID=HHID+0;    
    drop FSUBHH HHID;
run;

data h98f_h;
    set h98f_h;
    rename
        _FSUBHH=FSUBHH  
        _HHID=HHID;   
    drop esubhh dsubhh;
run;

%merge(w3assets,h98cs_r,h98pr_r,hhidpn);
*%merge(w3assets,w3assets,h98a_r,hhidpn);
%merge(w3assets,w3assets,h98j_h,hhid fsubhh);
%merge(w3assets,w3assets,h98f_h,hhid fsubhh);


data local.w3assets;
    set w3assets;
    if cohort=1;
run;


%mend;
%h;

%include cbrak3; *macro for coding all assets;

   
   data w3assets;
   set local.w3assets;
   run;


data test;
    set w3assets;
    if pn=fpn_fin;
run;
proc freq;
    tables finr3 ffinr /missing;
run;
    
%count(w3assets,hhid fsubhh,nhhid);

proc sort data=w3assets; by hhid fsubhh finr3;
data test1 test2;
    set w3assets;
    by hhid fsubhh finr3;
    if first.fsubhh then output test1;
    else output test2;
    run;

proc freq data=test1;
    tables
        nhhid*finr3*ffinr /list missing;
proc freq data=test2;
    tables
        nhhid*finr3*ffinr /list missing;


   %let rvars=   f119_1;
   %let spvars=s_f119_1;
   *%count(w3assets,hhid fsubhh,nhhid);
   %spouse(w3assets,&rvars,&spvars);   

   proc freq;
    tables f119_1*s_f119_1;
run;

    

/* Subset to HH level */    
            
proc sort data=w3assets; by hhid fsubhh finr3;
data w3assets;
    set w3assets;
    by hhid fsubhh finr3;
    if first.fsubhh;
    drop hhidpn s_f119_1;
run;
    
   
%vtic(w3assets);

proc freq;
    tables
        finr3*ffinr*f4830
        finr3*ffinr*f4856 /list missing;
run;

   /* construct lead indicators for rlst bsns */

   /* 
    * There are miising values in the lead variables
    * these are treated as if the value was 8 or 9
    */

data w3assets;
    set w3assets;
    lrlst=f4830;    
    if lrlst in(1,2) then lrlst=1; 
    lbsns=f4856;    
    if lbsns in(1,2) then lbsns=1; 
run;

/* there is a problem with the randomization indicator for rlst and bsns */
/* Fix it here */


proc print;
where
    (f117_1=1 and ((f4837>0 or f4836>0) or (f4833>0 and f4832=.) or (f4834>0 and f4832=.) )) or
    (f117_1=2 and ((f4832>0 or f4836>0) or (f4834>0 and f4833=.) )) or
    (f117_1=3 and (f4832>0 or f4833>0))
    ;                                                                                                          
var hhid fsubhh f117_1 f4832 f4833 f4834 f4837 f4836;
run;

proc print;
where
    (f119_1=1 and ((f4863>0 or f4862>0) or (f4860>0 and f4858=.) or (f4859>0 and f4858=.) ) ) or
    (f119_1=2 and ((f4858>0 or f4862>0) or (f4860>0 and f4859=.) ) ) or
    (f119_1=3 and (f4858>0 or f4859>0))
    ;                                                                                                          
var hhid fsubhh f119_1 f4858 f4859 f4860 f4862 f4863;
run;

/*


 OBS     HHID     FSUBHH    F117_1    F4832    F4833    F4834    F4837    F4836

  96    200181       0        1         .        .        1        5        1
 177    200341       0        2         .        .        9        .        .
 657    201273       0        1         .        .        9        .        .
1473    202759       0        3         5        3        .        .        .
1548    202885       0        3         5        5        1        .        .
1578    202933       0        2         8        .        .        .        .
1806    203350       0        3         .        1        .        3        .
2133    203951       0        3         .        1        .        5        .
2610    204828       0        3         9        .        .        .        .
2636    204873       0        2         5        1        .        .        .
3142    205830       0        3         5        8        .        .        .
3158    205863       0        2         .        .        1        5        1
3183    205918       0        2         .        .        5        .        .
3413    206326       0        1         .        .        1        .        3
3499    206482       0        2         5        1        .        .        .
3649    206735       0        3         5        5        1        .        .
3662    206758       0        3         .        1        .        1        .
3809    207030       0        1         .        3        .        .        .
3952    207280       0        2         5        1        .        .        .
3953    207281       0        2         5        1        .        .        .
4180    207669       0        1         .        1        .        1        .

 OBS     HHID     FSUBHH    F119_1    F4858    F4859    F4860    F4862    F4863

 657    201273       0        1         .        .        9        .        .
1098    202080       0        2         5        5        1        .        .
2180    204040       0        2         5        5        5        .        .
2362    204367       0        1         .        3        .        .        .
2890    205371       0        3         .        5        1        .        .
3183    205918       0        1         .        .        8        .        .
3213    205966       0        1         .        5        1        .        .
3287    206110       0        1         .        5        1        .        .
3341    206202       0        2         .        .        5        .        .
3499    206482       0        3         5        5        1        .        .
3692    206813       0        1         .        .        9        .        .
3827    207054       0        3         5        5        1        .        .
3829    207059       0        1         .        .        5        .        .
3838    207077       0        2         5        5        5        .        .
3846    207093       0        3         .        5        1        .        .
4275    207845       0        2         .        .        1        1        1
 */

    
data w3assets;
    set w3assets;
    
    if hhid=200181 and fsubhh=0 then f117_1=3;
    if hhid=200341 and fsubhh=0 then f117_1=3;
    if hhid=201273 and fsubhh=0 then f117_1=3;
    if hhid=202759 and fsubhh=0 then f117_1=1;
    if hhid=202885 and fsubhh=0 then f117_1=1;
    if hhid=202933 and fsubhh=0 then f117_1=1;
    if hhid=203350 and fsubhh=0 then f117_1=2;
    if hhid=203951 and fsubhh=0 then f117_1=2;
    if hhid=204828 and fsubhh=0 then f117_1=1;
    if hhid=204873 and fsubhh=0 then f117_1=1;
    if hhid=205830 and fsubhh=0 then f117_1=1;
    if hhid=205863 and fsubhh=0 then f117_1=3;
    if hhid=205918 and fsubhh=0 then f117_1=3;
    if hhid=206326 and fsubhh=0 then f117_1=3;
    if hhid=206482 and fsubhh=0 then f117_1=1;
    if hhid=206735 and fsubhh=0 then f117_1=1;
    if hhid=206758 and fsubhh=0 then f117_1=2;
    if hhid=207030 and fsubhh=0 then f117_1=2;
    if hhid=207280 and fsubhh=0 then f117_1=1;
    if hhid=207281 and fsubhh=0 then f117_1=1;
    if hhid=207669 and fsubhh=0 then f117_1=2;
    
    if hhid=201273 and fsubhh=0 then f119_1=3;
    if hhid=202080 and fsubhh=0 then f119_1=1;
    if hhid=204040 and fsubhh=0 then f119_1=1;
    if hhid=204367 and fsubhh=0 then f119_1=2;
    if hhid=205371 and fsubhh=0 then f119_1=2;
    if hhid=205918 and fsubhh=0 then f119_1=3; 
    if hhid=205966 and fsubhh=0 then f119_1=2;  
    if hhid=206110 and fsubhh=0 then f119_1=2;  
    if hhid=206202 and fsubhh=0 then f119_1=3;  
    if hhid=206482 and fsubhh=0 then f119_1=1;
    if hhid=206813 and fsubhh=0 then f119_1=3;  
    if hhid=207054 and fsubhh=0 then f119_1=1;
    if hhid=207059 and fsubhh=0 then f119_1=3;  
    if hhid=207077 and fsubhh=0 then f119_1=1;
    if hhid=207093 and fsubhh=0 then f119_1=2;
    if hhid=207845 and fsubhh=0 then f119_1=3;
run;


%cbrak3(rlst,lrlst,F4831,F117_1,F4832 F4833  F4834  F4835 F4837 F4836,2500  125000 500000 1000000,99999990);
%cbrak3(bsns,lbsns,F4857,F119_1,F4858 F4859  F4860  F4861 F4863 F4862,5000  10000  100000 1000000,99999990);


/****************************************/
/* construct lead indicators for IRA 1-3*/
/****************************************/
proc freq;
    tables finr3*f113_1*f4884*f4885*F4886*f4908*f4929 /list missing;
    run;

data w3assets;
    set w3assets;
        if f4884=1 then do;
            if f4885=1 then do;
                lira1=1;
                lira2=5;
                lira3=5;
                end;
            if f4885=2 then do;
                lira1=1;
                lira2=1;
                lira3=5;
                end;
            if f4885 in(3,4) then do;
                lira1=1;
                lira2=1;
                lira3=1;
                end;
            if f4885 in(8,9) then do;
                lira1=1;
                lira2=5;
                lira3=5;
                end;
            end;

        if f4884 in(2,5) then do;
            lira1=5;
            lira2=5;
            lira3=5;
            end;

        if f4884 in(8,9) then do;
            lira1=8;
            lira2=5;
            lira3=5;
            end;
run;


%cbrak3(ira1,lira1,F4887,F113_1,F4889 F4890  F4891  F4893 F4895 F4894,10000 25000  100000 400000 ,99999990);
%cbrak3(ira2,lira2,F4909,F113_1,F4910 F4911  F4912  F4914 F4916 F4915,10000 25000  100000 400000 ,99999990);
%cbrak3(ira3,lira3,F4930,F113_1,F4931 F4932  F4933  F4934 F4936 F4935,10000 25000  100000 400000 ,99999990);



/****************************************/
/* construct unified IRA variable       */
/****************************************/

proc freq;
tables 
d_ira13*d_ira23*d_ira33
diira13*diira23*diira33
c_ira13*c_ira23*c_ira33
d_ira13*d_ira23*d_ira33*i_ira13*i_ira23*i_ira33
/ list missing;

proc sort; by d_ira13;
proc means;
by d_ira13;
var a_ira13;

proc sort; by d_ira23;
proc means;
   by d_ira23;
   var a_ira23;
proc sort; by d_ira33;
proc means;
by d_ira33;
var a_ira33;

data w3assets;
    set w3assets;
    
    array a_s{3} a_ira13 a_ira23 a_ira33;
    array c_s{3} c_ira13 c_ira23 c_ira33;
    array lows{13} _temporary_  (0 1     10000 25000  100000 400000   0     0      10000    25000     100000    1         0       );
    array highs{13} _temporary_ (0 10000 25000 100000 400000 10000000 25000 100000 10000000 10000000  10000000  10000000  10000000);

*    if finr3=1 then do;    
        if d_ira13 ne . then do;
            low=0;
            high=0;
            do i=1 to 3;
                if a_s{i} ne . then do;
                    low=low+a_s{i};
                    high=high+a_s{i};
                    end;
                else do;
                    do j=1 to 13;
                        low=low+(c_s{i}=j)*lows{j};
                        high=high+(c_s{i}=j)*highs{j};
                        end;
                    end;
                end;
            if high=low then do;
                if high=0 then do;
                    d_ira3=0;
                    diira3=0;
                    c_ira3=0;
                    a_ira3=0;
                    i_ira3=0;
                    end;
                else do;
                    d_ira3=1;
                    diira3=0;
                    a_ira3=high;
                    c_ira3=
                        0*(a_ira3=0)+
                        1*(0      <  a_ira3 < 10000) +
                        2*(10000  <= a_ira3 < 25000) +
                        3*(25000  <= a_ira3 < 100000) +
                        4*(100000 <= a_ira3 < 400000) +
                        5*(400000 <= a_ira3);
                    i_ira3=0;
                    end;
                end;
            else do;
                L0= (0=low);
                L1= (0      <=  low and low <= 10000);
                L2= (10000  <= low and low <= 25000); 
                L3= (25000  <= low and low <= 100000);
                L4= (100000 <= low and low <= 400000);
                L5= (400000 <= low);                
                    
                H1= (0      <  high and high <= 10000);
                H2= (10000  <= high and high <= 25000); 
                H3= (25000  <= high and high <= 100000);
                H4= (100000 <= high and high <= 400000);
                H5= (400000 <= high);                
                    
                if      L1 and H1 then c_ira3=1;
                else if L2 and H2 then c_ira3=2;
                else if L3 and H3 then c_ira3=3;
                else if L4 and H4 then c_ira3=4;
                else if L5 and H5 then c_ira3=5;
                else if L1 and H2 then c_ira3=6;
                else if L1 and H3 then c_ira3=7;
                else if L2 and H5 then c_ira3=8;
                else if L3 and H5 then c_ira3=9;
                else if L4 and H5 then c_ira3=10;
                else if L1 and H5 and L0=0 then c_ira3=11;
                else if L0 and H5 then c_ira3=12;

                * Assign a few cases which don't fit the constructed brackets;
                else if L2 and H3 then c_ira3=7;
                else if L3 and H4 then c_ira3=8;
                else if L1 and H4 then c_ira3=7;
                
                
                d_ira3=1;
                diira3=0;
                i_ira3=1;
                if c_ira3=12 then do;
                    d_ira3=2; 
                    diira3=1;
                    end;
                end;
            end;
        else if d_ira13 eq . then do;
            d_ira3=2;
            diira3=1;
            i_ira3=1;
            c_ira3=12;
            end;
*        end;
run;    

/*
            1 0 0 0 0 0  0
            0 1 0 0 0 0  1
            0 0 1 0 0 0  2
            0 0 0 1 0 0  3
            0 0 0 0 1 0  4
            0 0 0 0 0 1  5
            0 1 1 0 0 0  6
            0 1 1 1 0 0  7
            0 0 1 1 1 1  8
            0 0 0 1 1 1  9
            0 0 0 0 1 1 10 
            0 1 1 1 1 1 11 
            1 1 1 1 1 1 12 

*/

proc freq;
    where finr3=1;
    tables d_ira3 diira3
      i_ira3 c_ira3
      d_ira3*c_ira3
      diira3*c_ira3
      i_ira3*c_ira3
   /   missing;
proc print;
    where c_ira3=.;
    var d_ira13 d_ira23 d_ira33 c_ira13 c_ira23 c_ira33 low high;


%cbrak3(stck,F5099,F5100,F114_1,F5101 F5102  F5103  F5104 F5106 F5105,2500  25000  125000 400000 ,99999990);
%cbrak3(bond,F5142,F5143,F115_1,F5144 F5145  F5146  F5148 F5150 F5149,2500  10000  100000 400000 ,99999990);
%cbrak3(chck,F5185,F5186,F116_1,F5187 F5188  F5189  F5190 F5192 F5191,5000  50000  150000 300000 ,99999990);
%cbrak3(cd  ,F5224,F5225,F118_1,F5226 F5227  F5228  F5229 F5231 F5230,2500  25000  125000 250000 ,99999990);
%cbrak3(trns,F5260,F5261,F120_1,F5262 F5263  F5264  NA    F5266 F5265,5000  25000  200000        ,9999990);
%cbrak3(othr,F5273,F5274,F124_1,F5275 F5276  F5277  NA    F5279 F5278,5000  50000  100000        ,9999990);
%cbrak3(debt,F5486,F5487,F121_1,F5488 F5489  F5490  NA    F5492 F5491,500   5000   50000         ,9999990);

data w3assets;
set w3assets;
if f2753 ne . then do;
    mobv=1;
    if f2753>99999990 then mobv=0;
    end;
        
if f2760 ne . then do;
    housv=1;
    if f2760>99999990 then housv=0;
end;
run;

proc freq;
/*all missing: f456 f497 f542 f518 f2745*f2747*f2748*f2749*f2750 */
    tables  f517 f721 f744 f288/ missing;
    tables finr3*f517*f721*f288*f744*f2741*f2742*f2743*f2744*f2746*f2751 /list missing;
    tables finr3*f517*f721*f288*f744*f2745*f2747*f2748*f2749*f2750 /list missing;
    tables finr3*housv*mobv*f2754*f2755*f2756*f2757 /list missing;
    tables finr3*housv*f2761*f2762*f2763*f2764*f2765*f2766 /list missing;
run;


data w3assets;
    set w3assets;
*    if finr3=1 then do;
        if f517=1 then do; * Nursing home ;
            if f721=1 then do; *Still own/rent;
                if f2742 ne 1 then do; *not mob home;
                    l_mob=0;
                    l_hous=2;
                    if f2743=1 then l_hous=1;
                    if f2743 in(2,7) then l_hous=0;
                    end;
                else if f2742=1 then do; *mob home;
                    l_mob=2;
                    l_hous=0;
                    if f2751 in(1,2,3) then l_mob=1;
                    if f2751 in(4,7) then l_mob=0;
                    end;
                end;
            else if f721=5 then do; *Does not own/rent;
                l_mob=0;
                l_hous=0;
                end;
            else do; *Does not own/rent;
                l_mob=0;
                l_hous=2;
                end;
            end;
        else if f517=5 then do; *Not in nursing home ;
            if f2742 eq 1 then do; *mob home;
                l_mob=2;
                l_hous=0;
                if f2751 in(1,2,3) then l_mob=1;
                if f2751 in(4,7) then l_mob=0;
                end;
            else if f2742 in(2,3,4,10,11,12,13,97) then do; *hous/apt;
                l_mob=0;
                l_hous=2;
                if f2741=1 then do; *Live farm;
                    if f2746 in(1,2) then l_hous=1;
                    if f2746 in(3,7) then l_hous=0;
                    end;
                else do;
                    if f2743=1 then l_hous=1;
                    if f2743 in(2,7) then l_hous=0;
                    end;
                end;
            else do;
                * NOTE: DK/RF to type of house and/or RF/DK to own house;
                * will be treated as missing ownership and therefore imputed;
                l_mob=0;
                l_hous=2;
                end;
            end;

        if f2742 ne . then do;
            mobhome3=(f2742=1);
            singfam3=(f2742=2);
            duplex3=(f2742=3);
            aptment3=(f2742=4);
            othhous3=(f2742 in(10,11,12,13,97));
            end;
        
        mobsite3 = (mobhome3=1 and f2751 in(1,2));   
        ownbldg3=(f2744=1);   
        farmlnd3=(f2741=1);
        farm3=(f2746=1); 
        *        end;
run;


proc freq;
    tables l_mob*l_hous*housv*mobv*f2741*f2742*f2743*f2744*f2746*f2751 /list missing;
    tables finr3*l_mob*housv*mobv*f2754*f2755*f2756*f2757 /list missing;
    tables finr3*l_hous*housv*f2761*f2762*f2763*f2764*f2765*f2766 /list missing;
run;

proc print;
    where (l_mob=0 and mobv=1) or (l_mob=2 and housv=1) or
        (l_hous=2 and housv=1) or (l_hous=2 and mobv=1) or (l_hous=2 and housv=0)
        or (l_hous=0 and housv=1);

    var l_hous  housv l_mob mobv f2753 f2760 f2741 f2742 f2743 f2744 f2746 f2751  
 mobhome3 singfam3 duplex3 aptment3 othhous3 mobsite3 ownbldg3 farmlnd3 farm3;
    
run;

/* Fix some inconsistencies */
data w3assets;
    set w3assets;

  /*
                                                                                   M    S         A    O    M    O    F
                                                                                   O    I    D    P    T    O    W    A
        L                                                                          B    N    U    T    H    B    N    R
        _    H    L                F           F    F     F    F    F    F    F    H    G    P    M    H    S    B    M    F
        H    O    _    M           2           2    2     2    2    2    2    2    O    F    L    E    O    I    L    L    A
  O     O    U    M    O           7           7    7     7    7    7    7    7    M    A    E    N    U    T    D    N    R
  B     U    S    O    B           5           6    4     4    4    4    4    5    E    M    X    T    S    E    G    D    M
  S     S    V    B    V           3           0    1     2    3    4    6    1    3    3    3    3    3    3    3    3    3

 257    0    1    2    .           .      120000    .     1    1    .    .    .    1    0    0    0    0    0    0    0    0
2077    0    1    0    .           .       17000    .     4    7    .    .    .    0    0    0    1    0    0    0    0    0
2876    0    1    2    .           .      100000    .     1    1    .    .    .    1    0    0    0    0    0    0    0    0
2902    0    1    2    .           .      100000    .     1    1    .    .    .    1    0    0    0    0    0    0    0    0
2917    0    1    2    .           .      175000    .     1    1    .    .    .    1    0    0    0    0    0    0    0    0
2940    2    .    0    1       25000           .    5    97    .    .    .    3    0    0    0    0    1    0    0    0    0
4012    0    1    2    .           .       75000    .     1    1    .    .    .    1    0    0    0    0    0    0    0    0


 */

        if (l_hous=0 and housv=1 and l_mob=2) then do;
            l_mob=0;
            l_hous=1;
            f2742=2;
            mobhome3=0;
            singfam3=1;
            end;
        if (l_hous=0 and housv=1 and l_mob=0) then do;
            l_hous=1;
            end;
        if (l_hous=2 and housv=. and l_mob=0 and mobv=1) then do;
            l_hous=0;
            l_mob=1;
            f2742=1;
            mobhome3=1;
            othhous3=0;
            end;
run;

proc freq;
    tables finr3*l_mob*housv*mobv*f2754*f2755*f2756*f2757 /list missing;
    tables finr3*l_hous*housv*f2761*f2762*f2763*f2764*f2765*f2766 /list missing;
run;


%cbrak3(mobh,l_mob,f2753,na,      NA    f2754  f2755  f2756 f2757 NA   ,5000  10000  20000  100000 ,99999990);
%cbrak3(hous,l_hous,f2760,f128_1,f2761 f2762 f2763  f2764 f2766 f2765,15000 50000  150000 500000 ,99999990);


proc freq;
    tables finr3*l_mob*l_hous*f2768m1*f2768m2 /list missing;
run;

data w3assets;
    set w3assets;
*    if finr3=1 then do;
        l_mort=0; l_mort2=0; l_loan=0;
        if l_hous=1 or l_mob=1 then do;
            if f2768m1=1 or f2768m2=1  then l_mort=1;
            if f2768m1=2 or f2768m2=2  then l_mort2=1;
            if f2768m1=3 or f2768m2=3  then l_loan=1;
            if f2768m1 in(8,9) then l_mort=2;
            end;
*        end;
    run;

proc freq;
    tables finr3*l_mob*l_hous*l_mort*l_mort2*l_loan*f2768m1*f2768m2 /list missing;
run;


%cbrak3(mort,l_mort,f2773,na,     NA    f2774  f2775  NA    f2776 NA   ,5000  20000  100000        ,9999990);
%cbrak3(2mrt,l_mort2,f2780,na,    NA    f2781  f2782  NA    f2783 NA   ,5000  20000  100000        ,9999990);
%cbrak3(loan,l_loan,f2787,na,     NA    f2788  f2789  NA    f2790 NA   ,5000  20000  100000        ,9999990);


   
data w3assets;
   set w3assets;
   format   
      c_rlst3 rlst3f.
      c_bsns3 bsns3f.
      c_ira13  ira3f.
      c_ira23  ira3f.
      c_ira33  ira3f.
      c_ira3   ira3f.
      c_stck3 stck3f.
      c_bond3 bond3f.
      c_cd3     cd3f.
      c_chck3 chck3f.
      c_trns3 trns3f.
      c_othr3 othr3f.
      c_debt3 debt3f.

      c_hous3 hous3f.
      c_mobh3 mobh3f.
      c_mort3 mort3f.
      c_2mrt3 mort3f.
      c_loan3 mort3f.
     ;
   run;


data w3assets;
   set w3assets;
   
   numrom3=f2903;
   nhood3=f2912;
   if nhood3 not in(8,9,.) then do; 
       hoodex3=(f2912=1);
       hoodvg3=(f2912=2);
       hoodgd3=(f2912=3);
       hoodfr3=(f2912=4);
       hoodpr3=(f2912=5);
       end;
   
   hcond3=f2904;
   if hcond3 not in(8,9,.) then do; 
       condex3=(f2904=1);
       condvg3=(f2904=2);
       condgd3=(f2904=3);
       condfr3=(f2904=4);
       condpr3=(f2904=5);
       end;


*****************************************************************;
* Label variables ;
*****************************************************************;
   
   label
       
       ownbldg3='own entire bldg w3'
       singfam3='single family house w3'
       duplex3='duplex house w3'
       mobhome3='mobile home w3'
       mobsite3='mob home and site w3'
       othhous3='other house type w3'
       aptment3='apartment w3'
       
       numrom3='number of rooms w3'
       
       farm3='live on farm w3'
       farmlnd3='own farm/land w3'
       
       nhood3='neighborhood condition w3'
       hcond3='house condition w3'
       
       hoodex3='neighborhood exc w3'
       hoodvg3='neighborhood v good w3'
       hoodgd3='neighborhood good w3'
       hoodfr3='neighborhood fair w3'
       hoodpr3='neighborhood poor w3'

       condex3='house condition exc w3'
       condvg3='house condition v gd w3'
       condgd3='house condition good w3'
       condfr3='house condition fair w3'
       condpr3='house condition poor w3'
       ;

   %label(rlst,w3);
   %label(bsns,w3);
   %label(ira,w3);
   %label(ira1,w3);
   %label(ira2,w3);
   %label(ira3,w3);
   %label(stck,w3);
   %label(bond,w3);
   %label(chck,w3);
   %label(cd,w3);
   %label(othr,w3);
   %label(trns,w3);
   %label(debt,w3);
   %label(mobh,w3);
   %label(hous,w3);
   %label(mort,w3);
   %label(2mrt,w3);
   %label(loan,w3);

   drop AHIGH ALOW HIGH LOW I J LBSNS L0-L5 H0-H5
       LIRA1 LIRA2 LIRA3 LOW LRLST L_HOUS L_LOAN L_MOB L_MORT L_MORT2
       mobv housv;

run;

%vtoc(w3assets);


proc freq;
tables %list4(c_,3);;

proc means;
var %list4(d_,3);;
var %list4(di,3);;
var %list4(i_,3);;
var %list4(b_,3);;
var %list4(a_,3);;

data local8.w3assets;
   set w3assets;
   keep  hhid fsubhh dsubhh ;
   keep %include "&thisfile..vars";;
run;
   
proc means;
    
x '/usr/xpg4/bin/rm ~/ribeiro/datagen/ahead3/code_e';   
x '/usr/xpg4/bin/rm ~/ribeiro/datagen/ahead3/code_cat';   

   /****************************************************/ 
   /*****************End of File************************/ 
   /****************************************************/ 

   %let thisfile=&lastfile;
   proc printto log="&thisfile..log" print="&thisfile..lst" ; run;

   /****************************************************/ 
   /****************************************************/ 
   /****************************************************/ 

