/*****************************************************************/
/* FILE:        	w3exit.sas                               */
/* PROJECT: 		Healthy, Wealthy, & Wise (AHEAD Data)    */
/* FACULTY:		Dan McFadden                             */
/* AUTHOR:		Angela Merrill/Tiago Ribeiro             */
/* LAST UPDATE:		Jan 2003                                 */
/* PROGRAM DESC:	Code Wave 3 exit interview               */
/* CONTACT:             tribeiro@econ.berkeley.edu               */
/*****************************************************************/
%global thisfile;
%let lastfile=&thisfile;
%let thisfile=w3exit;
proc printto log="&thisfile..log" print="&thisfile..lst" new; run;

%include "~/ribeiro/datagen/header.inc";

options ps=2000 ls=150;
 
%macro h;
    
x zcat "&rawe3/h98x_pr.ssd01.Z" > "&local/h98x_pr.ssd01";
x zcat "&rawe3/h98x_cs.ssd01.Z" > "&local/h98x_cs.ssd01";
x zcat "&rawe3/h98x_a.ssd01.Z"  > "&local/h98x_a.ssd01";
x zcat "&rawe3/h98x_b.ssd01.Z"  > "&local/h98x_b.ssd01";

x zcat "&rawe3/h98x_pc.ssd01.Z" > "&local/h98x_pc.ssd01";

x zcat "&rawe3/h98x_e.ssd01.Z"  > "&local/h98x_e.ssd01";
x zcat "&rawe3/h98x_g.ssd01.Z"  > "&local/h98x_g.ssd01";


proc contents data=local.h98d_h;
    
/****************************/
/* Preload Variables        */  
/****************************/

data h98x_pr;
     set local.h98x_pr;
     hhidpn=hhid*1000+pn;
run;

data h98x_cs;
     set local.h98x_cs;
     hhidpn=hhid*1000+pn;
     cohort=q461; *ahead is f461=1;
run;
    
data h98x_a;
     set local.h98x_a;
     hhidpn=hhid*1000+pn;
run;

data h98x_b;
     set local.h98x_b;
     hhidpn=hhid*1000+pn;
run;

data h98x_pc;
     set local.h98x_pc;
     hhidpn=hhid*1000+pn;
run;
    
data h98x_e;
     set local.h98x_e;
     hhidpn=hhid*1000+pn;
run;

data h98x_g;
     set local.h98x_g;
     hhidpn=hhid*1000+pn;
run;

%merge(w3x0,h98x_cs,h98x_pr,hhidpn);
%merge(w3x0,w3x0,h98x_cs,hhidpn);
%merge(w3x0,w3x0,h98x_a,hhidpn);
%merge(w3x0,w3x0,h98x_b,hhidpn);
%merge(w3x0,w3x0,h98x_pc,hhidpn);
%merge(w3x0,w3x0,h98x_e,hhidpn);
%merge(w3x0,w3x0,h98x_g,hhidpn);
    
*data local.w3x0;
data w3x0;
    set w3x0;
    if cohort=1;
    drop cohort;
    run;

x /bin/rm "&local/h98x_pr.ssd01";
x /bin/rm "&local/h98x_cs.ssd01";
x /bin/rm "&local/h98x_a.ssd01";
x /bin/rm "&local/h98x_b.ssd01";
x /bin/rm "&local/h98x_pc.ssd01";
x /bin/rm "&local/h98x_e.ssd01";
x /bin/rm "&local/h98x_g.ssd01";

%mend;
%h;


data w3x0;
*set local.w3x0;
set w3x0;
run;

%vtic(w3x0);

data w3x0;
set w3x0;
   
   %include 'w3exit/xdemog3.sas';
   %include 'w3exit/xhealth3.sas';
   %include 'w3exit/xcogn3.sas';
   %include 'w3exit/xadl_iadl3.sas';
   
run;

%vtoc(w3x0);

****************************************************;
* OUTPUT INDIVIDUAL-LEVEL DATASET;
****************************************************;
    
proc means nmiss n mean std min max;
    var %include "&thisfile..vars";;
run;


data local8.w3exit;		
   set w3x0;
   keep hhidpn;
   keep %include "&thisfile..vars";;
   run;


proc contents ;
proc means nmiss n mean std min max;
run;


   /****************************************************/ 
   /*****************End of File************************/ 
   /****************************************************/ 

   %let thisfile=&lastfile;
   proc printto log="&thisfile..log" print="&thisfile..lst"; run;

   /****************************************************/ 
   /****************************************************/ 
   /****************************************************/ 

