/*****************************************************************/
/* FILE:        	mapasst.sas                              */
/* PROJECT: 		Healthy, Wealthy, & Wise (AHEAD Data)    */
/* FACULTY:		Dan McFadden                             */
/* AUTHOR:		Tiago Ribeiro                            */
/* LAST UPDATE:		Jan 2003                                 */
/* PROGRAM DESC:	Create maps for categorical asset vars   */
/* CONTACT:             tribeiro@econ.berkeley.edu               */
/*****************************************************************/
include "~/ribeiro/datagen/header.inc";

%macro mapasst(typ,c);        
    %let c1=%eval(&c+1);
    %let n=0;
    %let v=c&n.&typ;
    %do %while(&n<&c);
        %let n=%eval(&n+1);
        %let v= &v c&n.&typ;
    %end;

    data asstcat.c_&typ;

        retain nmat -1 ;
        
        array v{&c1} &v ;
        
        do i=1 to &c1;
            nmat=nmat+1;
            c_&typ=nmat;
            
            do j=1 to &c1;
                v{j}=0;
                if i=j then v{j}=1;
                end;
            output;
            end;

        %if &c>1 %then %do;    
        do i=2 to &c;
            do j=i+1 to &c1;
                if ^(i=2 and j=&c1) then do;
                    nmat=nmat+1;
                    c_&typ=nmat;    
                    
                    do k=1 to &c1;
                        v{k}=0;
                        if i<=k and j>=k then v{k}=1;
                        end;
                    output;
                    end;
                end;
            end;
    
        nmat=nmat+1;
        c_&typ=nmat;    
        do i=1 to &c1;
            if i=1 then v{i}=0;
            else v{i}=1;
            end;
        output;
        %end;
        
        nmat=nmat+1;
        c_&typ=nmat;    
        do i=1 to &c1;
            v{i}=1;
            end;
        output;
        
        drop i j k nmat;
    run;
    
proc print;
    
    %mend;


%mapasst(rlst1,4);
%mapasst(bsns1,4);
%mapasst(ira1, 5);
%mapasst(stck1,5);
%mapasst(chck1,5);
%mapasst(bond1,5);
%mapasst(cd1,  5);
%mapasst(trns1,4);
%mapasst(othr1,4);
%mapasst(debt1,4);
%mapasst(lps11,2);
%mapasst(lps21,2);
%mapasst(lps31,2);
%mapasst(mobh1,4);
%mapasst(hous1,4);
%mapasst(mort1,1);
%mapasst(2mrt1,1);
%mapasst(loan1,1);
%mapasst(tinc1,8);
%mapasst(trust1,1);


%mapasst(rlst2,8);
%mapasst(bsns2,8);
%mapasst(ira2, 6);
%mapasst(ira12,6);
%mapasst(ira22,6);
%mapasst(ira32,6);
%mapasst(stck2,6);
%mapasst(bond2,6);
%mapasst(chck2,6);   
%mapasst(cd2,  6); 
%mapasst(trns2,6);   
%mapasst(othr2,4);         
%mapasst(debt2,4);      
%mapasst(mobh2,5); 
%mapasst(hous2,5);
%mapasst(mort2,4);
%mapasst(2mrt2,4);
%mapasst(loan2,4);
%mapasst(tinc2,8);



%mapasst(rlst3,5);
%mapasst(bsns3,5);
%mapasst(ira3, 5);
%mapasst(ira13,5);
%mapasst(ira23,5);
%mapasst(ira33,5);
%mapasst(stck3,5);
%mapasst(bond3,5);
%mapasst(chck3,5);
%mapasst(cd3,  5);
%mapasst(trns3,4);
%mapasst(othr3,4);
%mapasst(debt3,4);
%mapasst(mobh3,5);
%mapasst(hous3,5);
%mapasst(mort3,4);
%mapasst(2mrt3,4);
%mapasst(loan3,4);


%mapasst(rlst4,5);
%mapasst(bsns4,5);
%mapasst(ira4, 5);
%mapasst(ira14,5);
%mapasst(ira24,5);
%mapasst(ira34,5);
%mapasst(stck4,5);
%mapasst(bond4,5);
%mapasst(chck4,5);
%mapasst(cd4,  5);
%mapasst(trns4,4);
%mapasst(othr4,4);
%mapasst(debt4,4);
%mapasst(mobh4,5);
%mapasst(hous4,5);
%mapasst(mort4,4);
%mapasst(2mrt4,4);
%mapasst(loan4,4);

endsas;
%macro mapcat(c);        
    %let c1=%eval(&c+1);
    %let n=0;
    %let v=c&n.&typ;
    %do %while(&n<&c);
        %let n=%eval(&n+1);
        %let v= &v c&n.&typ;
    %end;

    data asstcat.mapcat&c;
        retain nmat -1 ;
        
        do i=1 to &c1;
            nmat=nmat+1;
            cati=nmat;
            
            do j=0 to &c1;
                if i=j then do;
                    catr=i-1;
                    output;
                    end;
                end;
            end;

        %if &c>1 %then %do;    
        do i=1 to &c;
            do j=i+1 to &c;
                if ^(i=1 and j=&c) then do;
                    nmat=nmat+1;
                    cati=nmat;

                    do k=1 to &c;
                        if i<=k and j>=k then  do;
                            catr=k;
                            output;
                            end;
                        end;
                    end;
                end;
            end;
        
        nmat=nmat+1;
        cati=nmat;
        do i=1 to &c;
            catr=i;
            output;
            end;
        %end;
        
        
        nmat=nmat+1;
        cati=nmat;
        do i=0 to &c;
            catr=i;
            output;
            end;
        
        drop i j k nmat;
    run;
    
proc print;
    
    %mend;

%mapcat(4);
%mapcat(5);
%mapcat(6);
%mapcat(7);
%mapcat(8);
%mapcat(9);

        
endsas;



