/*****************************************************************/
/* FILE:        	impamt.sas                               */
/* PROJECT: 		Healthy, Wealthy, & Wise (AHEAD Data)    */
/* FACULTY:		Dan McFadden                             */
/* AUTHOR:		Tiago Ribeiro                            */
/* LAST UPDATE:		Jan 2003                                 */
/* PROGRAM DESC:	Amount asset imputation waves 1-3        */
/* CONTACT:             tribeiro@econ.berkeley.edu               */
/*****************************************************************/
%include "~/ribeiro/datagen/header.inc";

%macro impamt(data,nimpv,cv,cntrlv,seed);

    
    data tmp;
        set &data; 
        flag=(&nimpv=.);
        keep &cntrlv &nimpv flag;
    run;

    proc means data=tmp;
        class flag &cv;
        var &nimpv;
    run;

    proc iml;
        use tmp var{&cntrlv &nimpv flag};
        read all var{&cntrlv &nimpv} into data0;
        read all var{flag} into flag;

        dono=data0[loc(flag=0),];
        impd=data0[loc(flag=1),];

        nd=nrow(dono);
        nc=ncol(data0)-1;
        
        do n=1 to nrow(impd);
            ctri=impd[n,1:nc];
            h=loc(dono[,1]=ctri[,1]);
            do i=2 to ncol(ctri);
                h1=setdif(h,loc(dono[,i]^=ctri[,i]));
                if ncol(h1)>0 then do;
                    h=h1;
                    end;
                end;
            hd1=dono[h,nc+1];
            r=round(ranuni(&seed)*nrow(hd1)+.5);
            impd[n,nc+1]=hd1[r];
            end;
        
        data0[loc(flag=1),]=impd;
        &nimpv=data0[,nc+1];
        edit tmp var{&nimpv};
        replace all var{&nimpv};
        edit &data var{&nimpv};
        replace all var{&nimpv};
    run;
    
    proc means data=tmp;
        class flag &cv;
        var &nimpv;
    run;

    %mend;


data w1astc;
    set local8.w1astc;
    array a_{*} %list2_4(a_,1,2) a_tinc1;
    array cn{*} %list2_4(cn,1,2) cntinc1;
    array an{*} %list2_4(an,1,2) antinc1;
    do i=1 to dim(a_);
        an{i}=a_{i};
        if cn{i}=0 then an{i}=0;
        end;
    drop i;
run;


%let data=w1astc;

%let seed=1;
%let var=hous;
%impamt(&data,an&var.1,cn&var.1,cn&var.1 nhhbppn,&seed);

%let seed=2;
%let var=mobh;
%impamt(&data,an&var.1,cn&var.1,cn&var.1 nhhbppn,&seed);

%let seed=3;
%let var=rlst;
%impamt(&data,an&var.1,cn&var.1,cn&var.1 nhhbppn,&seed);

%let seed=4;
%let var=trns;
%impamt(&data,an&var.1,cn&var.1,cn&var.1 nhhbppn,&seed);

%let seed=5;
%let var=bsns;
%impamt(&data,an&var.1,cn&var.1,cn&var.1 nhhbppn,&seed);

%let seed=6;
%let var=ira;
%impamt(&data,an&var.1,cn&var.1,cn&var.1 nhhbppn,&seed);

%let seed=7;
%let var=stck;
%impamt(&data,an&var.1,cn&var.1,cn&var.1 nhhbppn,&seed);

%let seed=8;
%let var=chck;
%impamt(&data,an&var.1,cn&var.1,cn&var.1 nhhbppn,&seed);

%let seed=9;
%let var=cd;
%impamt(&data,an&var.1,cn&var.1,cn&var.1 nhhbppn,&seed);

%let seed=10;
%let var=bond;
%impamt(&data,an&var.1,cn&var.1,cn&var.1 nhhbppn,&seed);

%let seed=11;
%let var=othr;
%impamt(&data,an&var.1,cn&var.1,cn&var.1 nhhbppn,&seed);

%let seed=12;
%let var=debt;
%impamt(&data,an&var.1,cn&var.1,cn&var.1 nhhbppn,&seed);

%let seed=13;
%let var=mort;
%impamt(&data,an&var.1,cn&var.1,cn&var.1 nhhbppn,&seed);

%let seed=14;
%let var=2mrt;
%impamt(&data,an&var.1,cn&var.1,cn&var.1 nhhbppn,&seed);

%let seed=15;
%let var=loan;
%impamt(&data,an&var.1,cn&var.1,cn&var.1 nhhbppn,&seed);

%let seed=16;
%let var=tinc;
%impamt(&data,an&var.1,cn&var.1,cn&var.1 nhhbppn,&seed);

%let pos1=anhous1 anmobh1 anrlst1 antrns1 anbsns1 anira1 anstck1 anchck1 ancd1 anbond1 anothr1; 
%let neg1=andebt1 anmort1 an2mrt1 anloan1;


data local8.w1asta;
    set w1astc;
    v2wlth1=sum(of &pos1)-sum(of &neg1);
    
    v2tinc1=antinc1;
    c2tinc1=cntinc1;

    label v2wlth1 ='total wealth (imp V.2), w1';
    label v2tinc1 ='total income (imp V.2), w1';
    label c2tinc1 ='imputed bracket tinc w1';

    %labeli(dn,rlst,w1);
    %labeli(dn,bsns,w1);
    %labeli(dn,ira,w1);
   *%labeli(dn,ira1,w1);
   *%labeli(dn,ira2,w1);
   *%labeli(dn,ira3,w1);
    %labeli(dn,stck,w1);
    %labeli(dn,bond,w1);
    %labeli(dn,chck,w1);
    %labeli(dn,cd,w1);
    %labeli(dn,othr,w1);
    %labeli(dn,trns,w1);
    %labeli(dn,debt,w1);
    %labeli(dn,mobh,w1);
    %labeli(dn,hous,w1);
    %labeli(dn,mort,w1);
    %labeli(dn,2mrt,w1);
    %labeli(dn,loan,w1);
    %labeli(dn,tinc,w1);

    %labeli(an,rlst,w1);
    %labeli(an,bsns,w1);
    %labeli(an,ira,w1);
   *%labeli(an,ira1,w1);
   *%labeli(an,ira2,w1);
   *%labeli(an,ira3,w1);
    %labeli(an,stck,w1);
    %labeli(an,bond,w1);
    %labeli(an,chck,w1);
    %labeli(an,cd,w1);
    %labeli(an,othr,w1);
    %labeli(an,trns,w1);
    %labeli(an,debt,w1);
    %labeli(an,mobh,w1);
    %labeli(an,hous,w1);
    %labeli(an,mort,w1);
    %labeli(an,2mrt,w1);
    %labeli(an,loan,w1);
    %labeli(an,tinc,w1);
   
run;

proc means;
    var &pos1 &neg1 v2wlth1 v2tinc1;
    run;
    
proc contents; run;
    
/* Wave 2 */

data w2astc;
    set local8.w2astc;
run;

data tmp;
    set local8.w1asta;
    keep hhid nhhbppn;
    keep %list2_4(cn,1,2) cntinc1;;
    keep %list2_4(an,1,2) antinc1;;
run;
%merge(w2astc,w2astc,tmp,hhid,1);


%let pr=an;
%let po=1;
%let an0=
    &pr.hous&po &pr.mobh&po &pr.rlst&po &pr.trns&po &pr.bsns&po
    &pr.stck&po &pr.chck&po &pr.cd&po   &pr.bond&po &pr.othr&po
    &pr.debt&po &pr.mort&po &pr.2mrt&po &pr.loan&po;

%let pr=an;
%let po=2;
%let an1=
    &pr.hous&po &pr.mobh&po &pr.rlst&po &pr.trns&po &pr.bsns&po
    &pr.stck&po &pr.chck&po &pr.cd&po   &pr.bond&po &pr.othr&po
    &pr.debt&po &pr.mort&po &pr.2mrt&po &pr.loan&po;

%let pr=a_;
%let po=2;
%let a_1=
    &pr.hous&po &pr.mobh&po &pr.rlst&po &pr.trns&po &pr.bsns&po
    &pr.stck&po &pr.chck&po &pr.cd&po   &pr.bond&po &pr.othr&po
    &pr.debt&po &pr.mort&po &pr.2mrt&po &pr.loan&po;

%let pr=cn;
%let po=2;
%let cn1=
    &pr.hous&po &pr.mobh&po &pr.rlst&po &pr.trns&po &pr.bsns&po
    &pr.stck&po &pr.chck&po &pr.cd&po   &pr.bond&po &pr.othr&po
    &pr.debt&po &pr.mort&po &pr.2mrt&po &pr.loan&po;

%let pr=cg;
%let po=2;
%let cg=
    &pr.hous&po &pr.mobh&po &pr.rlst&po &pr.trns&po &pr.bsns&po
    &pr.stck&po &pr.chck&po &pr.cd&po   &pr.bond&po &pr.othr&po
    &pr.debt&po &pr.mort&po &pr.2mrt&po &pr.loan&po;

data w2astc;
set w2astc;
    array an0{*} &an0 antinc1;
    array a_1{*} &a_1 a_tinc2;
    array an1{*} &an1 antinc2;
    array cn1{*} &cn1 cntinc2;
    array cg{*}  &cg  cgtinc2;

    do i=1 to dim(a_1);
        an1{i}=a_1{i};
        if cn1{i}=0 then an1{i}=0;
        cg{i}=an1{i}-an0{i};
        end;
    drop i;

    anira12=a_ira12;
    anira22=a_ira22;
    anira32=a_ira32;
    if cnira12=0 then anira12=0;    
    if cnira22=0 then anira22=0;    
    if cnira32=0 then anira32=0;    
    cgira12=anira12-anira1;
run;



%let data=w2astc;

%let seed=17;
%let var=hous;
%impamt(&data,an&var.2,cn&var.2,cn&var.2 cn&var.1 nhhdppn  nhhbppn,&seed);

%let seed=18;
%let var=mobh;
%impamt(&data,an&var.2,cn&var.2,cn&var.2 cn&var.1 nhhdppn  nhhbppn,&seed);

%let seed=19;
%let var=rlst;
%impamt(&data,an&var.2,cn&var.2,cn&var.2 cn&var.1 nhhdppn  nhhbppn,&seed);

%let seed=20;
%let var=trns;
%impamt(&data,an&var.2,cn&var.2,cn&var.2 cn&var.1 nhhdppn  nhhbppn,&seed);

%let seed=21;
%let var=bsns;
%impamt(&data,an&var.2,cn&var.2,cn&var.2 cn&var.1 nhhdppn  nhhbppn,&seed);

%let seed=22;
%let var=ira1;
%impamt(&data,an&var.2,cn&var.2,cn&var.2 cn&var   nhhdppn  nhhbppn,&seed);

%let seed=23;
%let var=ira2;
%impamt(&data,an&var.2,cn&var.2,nhhdppn cn&var.2,&seed);

%let seed=24;
%let var=ira3;
%impamt(&data,an&var.2,cn&var.2,cn&var.2 nhhdppn,&seed);

%let seed=25;
%let var=stck;
%impamt(&data,an&var.2,cn&var.2,cn&var.2 cn&var.1 nhhdppn  nhhbppn,&seed);

%let seed=26;
%let var=chck;
%impamt(&data,an&var.2,cn&var.2,cn&var.2 cn&var.1 nhhdppn  nhhbppn,&seed);

%let seed=27;
%let var=cd;
%impamt(&data,an&var.2,cn&var.2,cn&var.2 cn&var.1 nhhdppn  nhhbppn,&seed);

%let seed=28;
%let var=bond;
%impamt(&data,an&var.2,cn&var.2,cn&var.2 cn&var.1 nhhdppn  nhhbppn,&seed);

%let seed=29;
%let var=othr;
%impamt(&data,an&var.2,cn&var.2,cn&var.2 cn&var.1 nhhdppn  nhhbppn,&seed);

%let seed=30;
%let var=debt;
%impamt(&data,an&var.2,cn&var.2,cn&var.2 cn&var.1 nhhdppn  nhhbppn,&seed);

%let seed=31;
%let var=mort;
%impamt(&data,an&var.2,cn&var.2,cn&var.2 cn&var.1 nhhdppn  nhhbppn,&seed);

%let seed=32;
%let var=2mrt;
%impamt(&data,an&var.2,cn&var.2,cn&var.2 cn&var.1 nhhdppn  nhhbppn,&seed);

%let seed=33;
%let var=loan;
%impamt(&data,an&var.2,cn&var.2,cn&var.2 cn&var.1 nhhdppn  nhhbppn,&seed);

%let seed=34;
%let var=tinc;
%impamt(&data,an&var.2,cn&var.2,cn&var.2 cn&var.1 nhhdppn  nhhbppn,&seed);


%let pos2=anhous2 anmobh2 anrlst2 antrns2 anbsns2 anira12 anira22 anira32 anstck2 anchck2 ancd2 anbond2 anothr2; 
%let neg2=andebt2 anmort2 an2mrt2 anloan2;


data local8.w2asta;
    set w2astc;
    drop nhhbppn;
    drop %list2_4(cn,1,2);;
    drop %list2_4(an,1,2);;

    array an0{*} &an0 ;
    array a_1{*} &a_1 ;
    array an1{*} &an1 ;
    array cn1{*} &cn1 ;
    array cg{*}  &cg  ;

    do i=1 to dim(a_1);
        if cg{i}=. then cg{i}=an1{i}+an0{i};
        end;
    drop i;

    if cgira12=. then cgira12=anira12-anira1;

    v2wlth2=sum(of &pos2)-sum(of &neg2);
    
    v2tinc2=antinc2;
    c2tinc2=cntinc2;

    label v2wlth2 ='total wealth (imp V.2), w2';
    label v2tinc2 ='total income (imp V.2), w2';
    label c2tinc2 ='imputed bracket tinc w2';
    
    %labeli(dn,rlst,w2);
    %labeli(dn,bsns,w2);
   *%labeli(dn,ira,w2);
    %labeli(dn,ira1,w2);
    %labeli(dn,ira2,w2);
    %labeli(dn,ira3,w2);
    %labeli(dn,stck,w2);
    %labeli(dn,bond,w2);
    %labeli(dn,chck,w2);
    %labeli(dn,cd,w2);
    %labeli(dn,othr,w2);
    %labeli(dn,trns,w2);
    %labeli(dn,debt,w2);
    %labeli(dn,mobh,w2);
    %labeli(dn,hous,w2);
    %labeli(dn,mort,w2);
    %labeli(dn,2mrt,w2);
    %labeli(dn,loan,w2);
    %labeli(dn,tinc,w2);

    %labeli(an,rlst,w2);
    %labeli(an,bsns,w2);
   *%labeli(an,ira,w2);
    %labeli(an,ira1,w2);
    %labeli(an,ira2,w2);
    %labeli(an,ira3,w2);
    %labeli(an,stck,w2);
    %labeli(an,bond,w2);
    %labeli(an,chck,w2);
    %labeli(an,cd,w2);
    %labeli(an,othr,w2);
    %labeli(an,trns,w2);
    %labeli(an,debt,w2);
    %labeli(an,mobh,w2);
    %labeli(an,hous,w2);
    %labeli(an,mort,w2);
    %labeli(an,2mrt,w2);
    %labeli(an,loan,w2);
    %labeli(an,tinc,w2);

run;

proc means;
    var &pos2 &neg2 v2wlth2 v2tinc2;
run;

proc contents;

/* Wave 3 */

data w3astc;
    set local8.w3astc;
/* Fix loan dn */
        dnloan3=(c_loan3>0);
run;

data tmp;
    set local8.w2asta;
    keep hhid dsubhh nhhdppn;
    keep %list2_4(cn,2,1);;
    keep %list2_4(an,2,1);;
run;
%merge(w3astc,w3astc,tmp,hhid dsubhh,1);



%let an0=%list2_4(an,2,1);;
%let an1=%list2_4(an,3,1);;
%let a_1=%list2_4(a_,3,1);;
%let cn1=%list2_4(cn,3,1);;
%let cg =%list2_4(cg,3,1);;


data w3astc;
set w3astc;
    array an0{*} &an0 ;
    array a_1{*} &a_1 ;
    array an1{*} &an1 ;
    array cn1{*} &cn1 ;
    array cg{*}  &cg  ;

    do i=1 to dim(a_1);
        an1{i}=a_1{i};
        if cn1{i}=0 then an1{i}=0;
        cg{i}=an1{i}-an0{i};
        end;
    drop i;
run;



%let data=w3astc;

%let seed=35;
%let var=hous;
%impamt(&data,an&var.3,cn&var.3,cn&var.3 cn&var.2 nhhfppn nhhdppn,&seed);

%let seed=36;
%let var=mobh;
%impamt(&data,an&var.3,cn&var.3,cn&var.3 cn&var.2 nhhfppn nhhdppn,&seed);

%let seed=37;
%let var=rlst;
%impamt(&data,an&var.3,cn&var.3,cn&var.3 cn&var.2 nhhfppn nhhdppn,&seed);

%let seed=38;
%let var=trns;
%impamt(&data,an&var.3,cn&var.3,cn&var.3 cn&var.2 nhhfppn nhhdppn,&seed);

%let seed=39;
%let var=bsns;
%impamt(&data,an&var.3,cn&var.3,cn&var.3 cn&var.2 nhhfppn nhhdppn,&seed);

%let seed=40;
%let var=ira1;
%impamt(&data,an&var.3,cn&var.3,cn&var.3 cn&var.2 nhhfppn nhhdppn,&seed);

%let seed=41;
%let var=ira2;
%impamt(&data,an&var.3,cn&var.3, nhhfppn cn&var.3 nhhdppn cn&var.2,&seed);

%let seed=42;
%let var=ira3;
%impamt(&data,an&var.3,cn&var.3,cn&var.3 cn&var.2 nhhfppn nhhdppn,&seed);

%let seed=43;
%let var=stck;
%impamt(&data,an&var.3,cn&var.3,cn&var.3 cn&var.2 nhhfppn nhhdppn,&seed);

%let seed=44;
%let var=chck;
%impamt(&data,an&var.3,cn&var.3,cn&var.3 cn&var.2 nhhfppn nhhdppn,&seed);

%let seed=45;
%let var=cd;
%impamt(&data,an&var.3,cn&var.3,cn&var.3 cn&var.2 nhhfppn nhhdppn,&seed);

%let seed=46;
%let var=bond;
%impamt(&data,an&var.3,cn&var.3,cn&var.3 cn&var.2 nhhfppn nhhdppn,&seed);

%let seed=47;
%let var=othr;
%impamt(&data,an&var.3,cn&var.3,cn&var.3 cn&var.2 nhhfppn nhhdppn,&seed);

%let seed=48;
%let var=debt;
%impamt(&data,an&var.3,cn&var.3,cn&var.3 cn&var.2 nhhfppn nhhdppn,&seed);

%let seed=49;
%let var=mort;
%impamt(&data,an&var.3,cn&var.3,cn&var.3 cn&var.2 nhhfppn nhhdppn,&seed);

%let seed=50;
%let var=2mrt;
%impamt(&data,an&var.3,cn&var.3,cn&var.3 cn&var.2 nhhfppn nhhdppn,&seed);

%let seed=51;
%let var=loan;
%impamt(&data,an&var.3,cn&var.3,cn&var.3 cn&var.2 nhhfppn nhhdppn,&seed);


%let pos3=anhous3 anmobh3 anrlst3 antrns3 anbsns3 anira13 anira23 anira33 anstck3 anchck3 ancd3 anbond3 anothr3; 
%let neg3=andebt3 anmort3 an2mrt3 anloan3;


data local8.w3asta;
    set w3astc;
    drop nhhdppn;
    drop %list2_4(cn,2,1);;
    drop %list2_4(an,2,1);;

    array an0{*} &an0 ;
    array a_1{*} &a_1 ;
    array an1{*} &an1 ;
    array cn1{*} &cn1 ;
    array cg{*}  &cg  ;

    do i=1 to dim(a_1);
        if cg{i}=. then cg{i}=an1{i}+an0{i};
        end;
    drop i;

    v2wlth3=sum(of &pos3)-sum(of &neg3);

    label v2wlth3 ='total wealth (imp V.2), w3';

    %labeli(dn,rlst,w3);
    %labeli(dn,bsns,w3);
   *%labeli(dn,ira,w3);
    %labeli(dn,ira1,w3);
    %labeli(dn,ira2,w3);
    %labeli(dn,ira3,w3);
    %labeli(dn,stck,w3);
    %labeli(dn,bond,w3);
    %labeli(dn,chck,w3);
    %labeli(dn,cd,w3);
    %labeli(dn,othr,w3);
    %labeli(dn,trns,w3);
    %labeli(dn,debt,w3);
    %labeli(dn,mobh,w3);
    %labeli(dn,hous,w3);
    %labeli(dn,mort,w3);
    %labeli(dn,2mrt,w3);
    %labeli(dn,loan,w3);
    %labeli(dn,tinc,w3);

    %labeli(an,rlst,w3);
    %labeli(an,bsns,w3);
   *%labeli(an,ira,w3);
    %labeli(an,ira1,w3);
    %labeli(an,ira2,w3);
    %labeli(an,ira3,w3);
    %labeli(an,stck,w3);
    %labeli(an,bond,w3);
    %labeli(an,chck,w3);
    %labeli(an,cd,w3);
    %labeli(an,othr,w3);
    %labeli(an,trns,w3);
    %labeli(an,debt,w3);
    %labeli(an,mobh,w3);
    %labeli(an,hous,w3);
    %labeli(an,mort,w3);
    %labeli(an,2mrt,w3);
    %labeli(an,loan,w3);
    %labeli(an,tinc,w3);
    
run;

proc means;
    var &an1 v2wlth3;
run;

proc contents;
